package org.eclipse.jdt.internal.compiler.apt.model;

import java.io.IOException;
import java.io.Writer;
import org.eclipse.jdt.internal.compiler.lookup.LocalVariableBinding;
import org.eclipse.jdt.internal.compiler.lookup.LookupEnvironment;
import javax.lang.model.element.PackageElement;
import javax.lang.model.element.AnnotationValue;
import javax.lang.model.element.ExecutableElement;
import java.util.regex.Matcher;
import org.eclipse.jdt.internal.compiler.ast.FieldDeclaration;
import org.eclipse.jdt.internal.compiler.ast.AbstractMethodDeclaration;
import org.eclipse.jdt.internal.compiler.impl.ReferenceContext;
import org.eclipse.jdt.internal.compiler.ast.Javadoc;
import org.eclipse.jdt.internal.compiler.lookup.TypeConstants;
import org.eclipse.jdt.internal.compiler.lookup.PackageBinding;
import org.eclipse.jdt.internal.compiler.ast.TypeDeclaration;
import org.eclipse.jdt.internal.compiler.lookup.SourceTypeBinding;
import org.eclipse.jdt.core.compiler.CharOperation;
import javax.lang.model.element.Name;
import org.eclipse.jdt.internal.compiler.lookup.MethodVerifier;
import java.util.Map;
import org.eclipse.jdt.internal.compiler.lookup.MethodBinding;
import org.eclipse.jdt.internal.compiler.lookup.FieldBinding;
import java.util.LinkedHashSet;
import java.util.HashMap;
import javax.lang.model.element.TypeElement;
import java.util.Iterator;
import java.util.Set;
import java.util.Collections;
import org.eclipse.jdt.internal.compiler.lookup.AnnotationBinding;
import org.eclipse.jdt.internal.compiler.lookup.ParameterizedTypeBinding;
import org.eclipse.jdt.internal.compiler.lookup.ReferenceBinding;
import java.util.HashSet;
import java.util.ArrayList;
import javax.lang.model.element.ElementKind;
import javax.lang.model.element.AnnotationMirror;
import java.util.List;
import javax.lang.model.element.Element;
import org.eclipse.jdt.internal.compiler.apt.dispatch.BaseProcessingEnvImpl;
import java.util.regex.Pattern;
import javax.lang.model.util.Elements;

public class ElementsImpl implements Elements
{
    private static final Pattern INITIAL_DELIMITER;
    private final BaseProcessingEnvImpl _env;
    private static /* synthetic */ int[] $SWITCH_TABLE$javax$lang$model$element$ElementKind;
    
    static {
        INITIAL_DELIMITER = Pattern.compile("^\\s*/\\*+");
    }
    
    public ElementsImpl(BaseProcessingEnvImpl env) {
        this._env = env;
    }
    
    @Override
    public List<? extends AnnotationMirror> getAllAnnotationMirrors(Element e) {
        if (e.getKind() == ElementKind.CLASS && e instanceof TypeElementImpl) {
            List<AnnotationBinding> annotations = new ArrayList();
            Set<ReferenceBinding> annotationTypes = new HashSet();
            ReferenceBinding binding = (ReferenceBinding)((TypeElementImpl)e)._binding;
            boolean checkIfInherited = false;
            while (binding != null) {
                if ((binding instanceof ParameterizedTypeBinding)) {
                    binding = ((ParameterizedTypeBinding)binding).genericType();
                }
                AnnotationBinding[] packedAnnotationBindings;
                for (int length = (packedAnnotationBindings = Factory.getPackedAnnotationBindings(binding.getAnnotations())).length, i = 0; i < length; ++i) {
                    AnnotationBinding annotation = packedAnnotationBindings[i];
                    if (annotation != null) {
                        ReferenceBinding annotationType = annotation.getAnnotationType();
                        if ((!checkIfInherited || (annotationType.getAnnotationTagBits() & 0x1000000000000L) != 0x0L) && !annotationTypes.contains(annotationType)) {
                            annotationTypes.add(annotationType);
                            annotations.add(annotation);
                        }
                    }
                }
                binding = binding.superclass();
                checkIfInherited = true;
            }
            List<AnnotationMirror> list = new ArrayList(annotations.size());
            for (AnnotationBinding annotation2 : annotations) {
                list.add(this._env.getFactory().newAnnotationMirror(annotation2));
            }
            return Collections.unmodifiableList(list);
        }
        return e.getAnnotationMirrors();
    }
    
    @Override
    public List<? extends Element> getAllMembers(TypeElement type) {
        if (type == null || !(type instanceof TypeElementImpl)) {
            return Collections.emptyList();
        }
        ReferenceBinding binding = (ReferenceBinding)((TypeElementImpl)type)._binding;
        Map<String, ReferenceBinding> types = new HashMap();
        List<FieldBinding> fields = new ArrayList();
        Map<String, Set<MethodBinding>> methods = new HashMap();
        Set<ReferenceBinding> superinterfaces = new LinkedHashSet();
        boolean ignoreVisibility = true;
        while (binding != null) {
            this.addMembers(binding, ignoreVisibility, types, fields, methods);
            Set<ReferenceBinding> newfound = new LinkedHashSet();
            this.collectSuperInterfaces(binding, superinterfaces, newfound);
            for (ReferenceBinding superinterface : newfound) {
                this.addMembers(superinterface, false, types, fields, methods);
            }
            superinterfaces.addAll(newfound);
            binding = binding.superclass();
            ignoreVisibility = false;
        }
        List<Element> allMembers = new ArrayList();
        for (ReferenceBinding nestedType : types.values()) {
            allMembers.add(this._env.getFactory().newElement(nestedType));
        }
        for (FieldBinding field : fields) {
            allMembers.add(this._env.getFactory().newElement(field));
        }
        for (Set<MethodBinding> sameNamedMethods : methods.values()) {
            for (MethodBinding method : sameNamedMethods) {
                allMembers.add(this._env.getFactory().newElement(method));
            }
        }
        return allMembers;
    }
    
    private void collectSuperInterfaces(ReferenceBinding type, Set<ReferenceBinding> existing, Set<ReferenceBinding> newfound) {
        ReferenceBinding[] superInterfaces;
        for (int length = (superInterfaces = type.superInterfaces()).length, i = 0; i < length; ++i) {
            ReferenceBinding superinterface = superInterfaces[i];
            if (!existing.contains(superinterface) && !newfound.contains(superinterface)) {
                newfound.add(superinterface);
                this.collectSuperInterfaces(superinterface, existing, newfound);
            }
        }
    }
    
    private void addMembers(ReferenceBinding binding, boolean ignoreVisibility, Map<String, ReferenceBinding> types, List<FieldBinding> fields, Map<String, Set<MethodBinding>> methods) {
        ReferenceBinding[] memberTypes;
        for (int length = (memberTypes = binding.memberTypes()).length, i = 0; i < length; ++i) {
            ReferenceBinding subtype = memberTypes[i];
            if (ignoreVisibility || !subtype.isPrivate()) {
                String name = new String(subtype.sourceName());
                if (types.get(name) == null) {
                    types.put(name, subtype);
                }
            }
        }
        FieldBinding[] fields2;
        for (int length2 = (fields2 = binding.fields()).length, j = 0; j < length2; ++j) {
            FieldBinding field = fields2[j];
            if (ignoreVisibility || !field.isPrivate()) {
                fields.add(field);
            }
        }
        MethodBinding[] methods2;
        for (int length3 = (methods2 = binding.methods()).length, k = 0; k < length3; ++k) {
            MethodBinding method = methods2[k];
            if (!method.isSynthetic() && (ignoreVisibility || (!method.isPrivate() && !method.isConstructor()))) {
                String methodName = new String(method.selector);
                Set<MethodBinding> sameNamedMethods = (Set)methods.get(methodName);
                if (sameNamedMethods == null) {
                    sameNamedMethods = new HashSet(4);
                    methods.put(methodName, sameNamedMethods);
                    sameNamedMethods.add(method);
                }
                else {
                    boolean unique = true;
                    if (!ignoreVisibility) {
                        for (MethodBinding existing : sameNamedMethods) {
                            MethodVerifier verifier = this._env.getLookupEnvironment().methodVerifier();
                            if (verifier.doesMethodOverride(existing, method)) {
                                unique = false;
                                break;
                            }
                            continue;
                        }
                    }
                    if (unique) {
                        sameNamedMethods.add(method);
                    }
                }
            }
        }
    }
    
    @Override
    public Name getBinaryName(TypeElement type) {
        TypeElementImpl typeElementImpl = (TypeElementImpl)type;
        ReferenceBinding referenceBinding = (ReferenceBinding)typeElementImpl._binding;
        return new NameImpl(CharOperation.replaceOnCopy(referenceBinding.constantPoolName(), '/', '.'));
    }
    
    @Override
    public String getConstantExpression(Object value) {
        if (!(value instanceof Integer) && !(value instanceof Byte) && !(value instanceof Float) && !(value instanceof Double) && !(value instanceof Long) && !(value instanceof Short) && !(value instanceof Character) && !(value instanceof String) && !(value instanceof Boolean)) {
            throw new IllegalArgumentException("Not a valid wrapper type : " + value.getClass());
        }
        if ((value instanceof Character)) {
            StringBuilder builder = new StringBuilder();
            builder.append('\'').append(value).append('\'');
            return String.valueOf(builder);
        }
        if ((value instanceof String)) {
            StringBuilder builder = new StringBuilder();
            builder.append('\"').append(value).append('\"');
            return String.valueOf(builder);
        }
        if ((value instanceof Float)) {
            StringBuilder builder = new StringBuilder();
            builder.append(value).append('f');
            return String.valueOf(builder);
        }
        if ((value instanceof Long)) {
            StringBuilder builder = new StringBuilder();
            builder.append(value).append('L');
            return String.valueOf(builder);
        }
        if ((value instanceof Short)) {
            StringBuilder builder = new StringBuilder();
            builder.append("(short)").append(value);
            return String.valueOf(builder);
        }
        if ((value instanceof Byte)) {
            StringBuilder builder = new StringBuilder();
            builder.append("(byte)0x");
            int intValue = (byte)value;
            String hexString = Integer.toHexString(intValue & 0xFF);
            if (hexString.length() < 2) {
                builder.append('0');
            }
            builder.append(hexString);
            return String.valueOf(builder);
        }
        else {
            return String.valueOf(value);
        }
    }
    
    @Override
    public String getDocComment(Element e) {
        char[] unparsed = this.getUnparsedDocComment(e);
        return formatJavadoc(unparsed);
    }
    
    private char[] getUnparsedDocComment(Element e) {
        Javadoc javadoc = null;
        ReferenceContext referenceContext = null;
        switch ($SWITCH_TABLE$javax$lang$model$element$ElementKind()[e.getKind().ordinal()]) {
            case 2:
            case 3:
            case 4:
            case 5: {
                TypeElementImpl typeElementImpl = (TypeElementImpl)e;
                ReferenceBinding referenceBinding = (ReferenceBinding)typeElementImpl._binding;
                if ((referenceBinding instanceof SourceTypeBinding)) {
                    SourceTypeBinding sourceTypeBinding = (SourceTypeBinding)referenceBinding;
                    referenceContext = sourceTypeBinding.scope.referenceContext;
                    javadoc = ((TypeDeclaration)referenceContext).javadoc;
                    break;
                }
                break;
            }
            case 1: {
                PackageElementImpl packageElementImpl = (PackageElementImpl)e;
                PackageBinding packageBinding = (PackageBinding)packageElementImpl._binding;
                char[][] compoundName = CharOperation.arrayConcat(packageBinding.compoundName, TypeConstants.PACKAGE_INFO_NAME);
                ReferenceBinding type = this._env.getLookupEnvironment().getType(compoundName);
                if (type != null && type.isValidBinding() && type instanceof SourceTypeBinding) {
                    SourceTypeBinding sourceTypeBinding2 = (SourceTypeBinding)type;
                    referenceContext = sourceTypeBinding2.scope.referenceContext;
                    javadoc = ((TypeDeclaration)referenceContext).javadoc;
                    break;
                }
                break;
            }
            case 11:
            case 12: {
                ExecutableElementImpl executableElementImpl = (ExecutableElementImpl)e;
                MethodBinding methodBinding = (MethodBinding)executableElementImpl._binding;
                AbstractMethodDeclaration sourceMethod = methodBinding.sourceMethod();
                if (sourceMethod != null) {
                    javadoc = sourceMethod.javadoc;
                    referenceContext = sourceMethod;
                    break;
                }
                break;
            }
            case 6:
            case 7: {
                VariableElementImpl variableElementImpl = (VariableElementImpl)e;
                FieldBinding fieldBinding = (FieldBinding)variableElementImpl._binding;
                FieldDeclaration sourceField = fieldBinding.sourceField();
                if (sourceField != null) {
                    javadoc = sourceField.javadoc;
                    if ((fieldBinding.declaringClass instanceof SourceTypeBinding)) {
                        SourceTypeBinding sourceTypeBinding3 = (SourceTypeBinding)fieldBinding.declaringClass;
                        referenceContext = sourceTypeBinding3.scope.referenceContext;
                        break;
                    }
                    break;
                }
                else {
                    break;
                }
            }
            default: {
                return null;
            }
        }
        if (javadoc != null && referenceContext != null) {
            char[] contents = referenceContext.compilationResult().getCompilationUnit().getContents();
            if (contents != null) {
                return CharOperation.subarray(contents, javadoc.sourceStart, javadoc.sourceEnd - 1);
            }
        }
        return null;
    }
    
    private static String formatJavadoc(char[] unparsed) {
        if (unparsed == null || unparsed.length < 5) {
            return null;
        }
        String[] lines = new String(unparsed).split("\n");
        Matcher delimiterMatcher = ElementsImpl.INITIAL_DELIMITER.matcher(lines[0]);
        if (!delimiterMatcher.find()) {
            return null;
        }
        int iOpener = delimiterMatcher.end();
        lines[0] = lines[0].substring(iOpener);
        if (lines.length == 1) {
            StringBuilder sb2 = new StringBuilder();
            char[] chars2 = lines[0].toCharArray();
            boolean startingWhitespaces = true;
            for (char c2 : chars2) {
                if (Character.isWhitespace(c2)) {
                    if (!startingWhitespaces) {
                        sb2.append(c2);
                    }
                }
                else {
                    startingWhitespaces = false;
                    sb2.append(c2);
                }
            }
            return sb2.toString();
        }
        int firstLine = (lines[0].trim().length() > 0) ? 0 : 1;
        int lastLine = (lines[lines.length - 1].trim().length() > 0) ? (lines.length - 1) : (lines.length - 2);
        StringBuilder sb = new StringBuilder();
        if (lines[0].length() != 0 && firstLine == 1) {
            sb.append('\n');
        }
        boolean preserveLineSeparator = lines[0].length() == 0;
        for (int line = firstLine; line <= lastLine; ++line) {
            char[] chars = lines[line].toCharArray();
            int starsIndex = getStars(chars);
            int leadingWhitespaces = 0;
            boolean recordLeadingWhitespaces = true;
            for (int i = 0, max = chars.length; i < max; ++i) {
                char c = chars[i];
                switch (c) {
                    case ' ': {
                        if (starsIndex == -1) {
                            if (recordLeadingWhitespaces) {
                                ++leadingWhitespaces;
                                break;
                            }
                            sb.append(c);
                            break;
                        }
                        else {
                            if (i >= starsIndex) {
                                sb.append(c);
                                break;
                            }
                            break;
                        }
                    }
                    default: {
                        recordLeadingWhitespaces = false;
                        if (leadingWhitespaces != 0) {
                            int numberOfTabs = leadingWhitespaces / 8;
                            if (numberOfTabs != 0) {
                                for (int j = 0, max2 = numberOfTabs; j < max2; ++j) {
                                    sb.append("        ");
                                }
                                if (leadingWhitespaces % 8 >= 1) {
                                    sb.append(' ');
                                }
                            }
                            else if (line != 0) {
                                for (int j = 0, max2 = leadingWhitespaces; j < max2; ++j) {
                                    sb.append(' ');
                                }
                            }
                            leadingWhitespaces = 0;
                            sb.append(c);
                            break;
                        }
                        else if (c == '\t') {
                            if (i >= starsIndex) {
                                sb.append(c);
                                break;
                            }
                            break;
                        }
                        else {
                            if (c != '*' || i > starsIndex) {
                                sb.append(c);
                                break;
                            }
                            break;
                        }
                    }
                }
            }
            int end = lines.length - 1;
            if (line < end) {
                sb.append('\n');
            }
            else if (preserveLineSeparator && line == end) {
                sb.append('\n');
            }
        }
        return sb.toString();
    }
    
    private static int getStars(char[] line) {
        int i = 0;
        int max = line.length;
        while (i < max) {
            char c = line[i];
            if (!Character.isWhitespace(c)) {
                if (c == '*') {
                    int j = i + 1;
                    while (j < max) {
                        if (line[j] != '*') {
                            return j;
                        }
                        ++j;
                    }
                    return max - 1;
                }
                break;
            }
            else {
                ++i;
            }
        }
        return -1;
    }
    
    @Override
    public Map<? extends ExecutableElement, ? extends AnnotationValue> getElementValuesWithDefaults(AnnotationMirror a) {
        return ((AnnotationMirrorImpl)a).getElementValuesWithDefaults();
    }
    
    @Override
    public Name getName(CharSequence cs) {
        return new NameImpl(cs);
    }
    
    @Override
    public PackageElement getPackageElement(CharSequence name) {
        LookupEnvironment le = this._env.getLookupEnvironment();
        if (name.length() == 0) {
            return new PackageElementImpl(this._env, le.defaultPackage);
        }
        char[] packageName = name.toString().toCharArray();
        PackageBinding packageBinding = le.createPackage(CharOperation.splitOn('.', packageName));
        if (packageBinding == null) {
            return null;
        }
        return new PackageElementImpl(this._env, packageBinding);
    }
    
    @Override
    public PackageElement getPackageOf(Element type) {
        switch ($SWITCH_TABLE$javax$lang$model$element$ElementKind()[type.getKind().ordinal()]) {
            case 2:
            case 3:
            case 4:
            case 5: {
                TypeElementImpl typeElementImpl = (TypeElementImpl)type;
                ReferenceBinding referenceBinding = (ReferenceBinding)typeElementImpl._binding;
                return (PackageElement)this._env.getFactory().newElement(referenceBinding.fPackage);
            }
            case 1: {
                return (PackageElement)type;
            }
            case 11:
            case 12: {
                ExecutableElementImpl executableElementImpl = (ExecutableElementImpl)type;
                MethodBinding methodBinding = (MethodBinding)executableElementImpl._binding;
                return (PackageElement)this._env.getFactory().newElement(methodBinding.declaringClass.fPackage);
            }
            case 6:
            case 7: {
                VariableElementImpl variableElementImpl = (VariableElementImpl)type;
                FieldBinding fieldBinding = (FieldBinding)variableElementImpl._binding;
                return (PackageElement)this._env.getFactory().newElement(fieldBinding.declaringClass.fPackage);
            }
            case 8: {
                VariableElementImpl variableElementImpl = (VariableElementImpl)type;
                LocalVariableBinding localVariableBinding = (LocalVariableBinding)variableElementImpl._binding;
                return (PackageElement)this._env.getFactory().newElement(localVariableBinding.declaringScope.classScope().referenceContext.binding.fPackage);
            }
            case 9:
            case 10:
            case 13:
            case 14:
            case 15:
            case 16: {
                return null;
            }
            default: {
                return null;
            }
        }
    }
    
    @Override
    public TypeElement getTypeElement(CharSequence name) {
        LookupEnvironment le = this._env.getLookupEnvironment();
        char[][] compoundName = CharOperation.splitOn('.', name.toString().toCharArray());
        ReferenceBinding binding = le.getType(compoundName);
        if (binding == null) {
            ReferenceBinding topLevelBinding = null;
            int topLevelSegments = compoundName.length;
            while (--topLevelSegments > 0) {
                char[][] topLevelName = new char[topLevelSegments][];
                for (int i = 0; i < topLevelSegments; ++i) {
                    topLevelName[i] = compoundName[i];
                }
                topLevelBinding = le.getType(topLevelName);
                if (topLevelBinding != null) {
                    break;
                }
                continue;
            }
            if (topLevelBinding == null) {
                return null;
            }
            binding = topLevelBinding;
            for (int j = topLevelSegments; binding != null && j < compoundName.length; binding = binding.getMemberType(compoundName[j]), ++j) {}
        }
        if (binding == null) {
            return null;
        }
        return new TypeElementImpl(this._env, binding, null);
    }
    
    @Override
    public boolean hides(Element hider, Element hidden) {
        if (hidden == null) {
            throw new NullPointerException();
        }
        return ((ElementImpl)hider).hides(hidden);
    }
    
    @Override
    public boolean isDeprecated(Element e) {
        return e instanceof ElementImpl && (((ElementImpl)e)._binding.getAnnotationTagBits() & 0x400000000000L) != 0x0L;
    }
    
    @Override
    public boolean overrides(ExecutableElement overrider, ExecutableElement overridden, TypeElement type) {
        if (overridden == null || type == null) {
            throw new NullPointerException();
        }
        return ((ExecutableElementImpl)overrider).overrides(overridden, type);
    }
    
    @Override
    public void printElements(Writer w, Element... elements) {
        String lineSeparator = System.getProperty("line.separator");
        for (Element element : elements) {
            try {
                w.write(element.toString());
                w.write(lineSeparator);
            }
            catch (IOException ex) {}
        }
        try {
            w.flush();
        }
        catch (IOException ex2) {}
    }
    
    @Override
    public boolean isFunctionalInterface(TypeElement type) {
        if (type != null && type.getKind() == ElementKind.INTERFACE) {
            ReferenceBinding binding = (ReferenceBinding)((TypeElementImpl)type)._binding;
            if ((binding instanceof SourceTypeBinding)) {
                return binding.isFunctionalInterface(((SourceTypeBinding)binding).scope);
            }
        }
        return false;
    }
    
    static /* synthetic */ int[] $SWITCH_TABLE$javax$lang$model$element$ElementKind() {
        int[] $switch_TABLE$javax$lang$model$element$ElementKind = ElementsImpl.$SWITCH_TABLE$javax$lang$model$element$ElementKind;
        if ($switch_TABLE$javax$lang$model$element$ElementKind != null) {
            return $switch_TABLE$javax$lang$model$element$ElementKind;
        }
        int[] $switch_TABLE$javax$lang$model$element$ElementKind2 = new int[ElementKind.values().length];
        try {
            $switch_TABLE$javax$lang$model$element$ElementKind2[ElementKind.ANNOTATION_TYPE.ordinal()] = 4;
        }
        catch (NoSuchFieldError noSuchFieldError) {}
        try {
            $switch_TABLE$javax$lang$model$element$ElementKind2[ElementKind.CLASS.ordinal()] = 3;
        }
        catch (NoSuchFieldError noSuchFieldError2) {}
        try {
            $switch_TABLE$javax$lang$model$element$ElementKind2[ElementKind.CONSTRUCTOR.ordinal()] = 12;
        }
        catch (NoSuchFieldError noSuchFieldError3) {}
        try {
            $switch_TABLE$javax$lang$model$element$ElementKind2[ElementKind.ENUM.ordinal()] = 2;
        }
        catch (NoSuchFieldError noSuchFieldError4) {}
        try {
            $switch_TABLE$javax$lang$model$element$ElementKind2[ElementKind.ENUM_CONSTANT.ordinal()] = 6;
        }
        catch (NoSuchFieldError noSuchFieldError5) {}
        try {
            $switch_TABLE$javax$lang$model$element$ElementKind2[ElementKind.EXCEPTION_PARAMETER.ordinal()] = 10;
        }
        catch (NoSuchFieldError noSuchFieldError6) {}
        try {
            $switch_TABLE$javax$lang$model$element$ElementKind2[ElementKind.FIELD.ordinal()] = 7;
        }
        catch (NoSuchFieldError noSuchFieldError7) {}
        try {
            $switch_TABLE$javax$lang$model$element$ElementKind2[ElementKind.INSTANCE_INIT.ordinal()] = 14;
        }
        catch (NoSuchFieldError noSuchFieldError8) {}
        try {
            $switch_TABLE$javax$lang$model$element$ElementKind2[ElementKind.INTERFACE.ordinal()] = 5;
        }
        catch (NoSuchFieldError noSuchFieldError9) {}
        try {
            $switch_TABLE$javax$lang$model$element$ElementKind2[ElementKind.LOCAL_VARIABLE.ordinal()] = 9;
        }
        catch (NoSuchFieldError noSuchFieldError10) {}
        try {
            $switch_TABLE$javax$lang$model$element$ElementKind2[ElementKind.METHOD.ordinal()] = 11;
        }
        catch (NoSuchFieldError noSuchFieldError11) {}
        try {
            $switch_TABLE$javax$lang$model$element$ElementKind2[ElementKind.OTHER.ordinal()] = 16;
        }
        catch (NoSuchFieldError noSuchFieldError12) {}
        try {
            $switch_TABLE$javax$lang$model$element$ElementKind2[ElementKind.PACKAGE.ordinal()] = 1;
        }
        catch (NoSuchFieldError noSuchFieldError13) {}
        try {
            $switch_TABLE$javax$lang$model$element$ElementKind2[ElementKind.PARAMETER.ordinal()] = 8;
        }
        catch (NoSuchFieldError noSuchFieldError14) {}
        try {
            $switch_TABLE$javax$lang$model$element$ElementKind2[ElementKind.RESOURCE_VARIABLE.ordinal()] = 17;
        }
        catch (NoSuchFieldError noSuchFieldError15) {}
        try {
            $switch_TABLE$javax$lang$model$element$ElementKind2[ElementKind.STATIC_INIT.ordinal()] = 13;
        }
        catch (NoSuchFieldError noSuchFieldError16) {}
        try {
            $switch_TABLE$javax$lang$model$element$ElementKind2[ElementKind.TYPE_PARAMETER.ordinal()] = 15;
        }
        catch (NoSuchFieldError noSuchFieldError17) {}
        return ElementsImpl.$SWITCH_TABLE$javax$lang$model$element$ElementKind = $switch_TABLE$javax$lang$model$element$ElementKind2;
    }
}
